@@ -12,7 +12,7 @@ _api = sciter.SciterAPI()
 class Window(sciter.platform.BaseWindow, sciter.host.Host, sciter.event.EventHandler):
     """Basic Sciter window."""
 
-    def __init__(self, ismain=False, ispopup=False, ischild=False, resizeable=True, parent=None, uni_theme=False, debug=True, pos=None, size=None):
+    def __init__(self, ismain=False, ispopup=False, ischild=False, resizeable=True, parent=None, uni_theme=False, debug=True, pos=None, size=None, subscription=None):
         """Create a new window and setup the sciter and dom callbacks."""
         super().__init__()
         from sciter.capi.scdef import SCITER_CREATE_WINDOW_FLAGS
@@ -32,7 +32,13 @@ class Window(sciter.platform.BaseWindow, sciter.host.Host, sciter.event.EventHan
 
         if debug:
             flags = flags | SCITER_CREATE_WINDOW_FLAGS.SW_ENABLE_DEBUG
-            self.setup_debug()
+
+        # New windows can be inspectable.
+        # Debug messages will be printed always.
+        # If you need to disable the debug output,
+        # either call `frame.setup_debug(debug_output=False)`
+        # or override `Host.on_debug_output`.
+        self.setup_debug(debug_windows=debug, debug_output=True)
 
         self.window_flags = flags
         self._title_changed = False
@@ -49,12 +55,12 @@ class Window(sciter.platform.BaseWindow, sciter.host.Host, sciter.event.EventHan
         if not pos and not size:
             rect = None
 
-        self.hwnd = self._create(flags, rect=rect, parent=None)
+        self.hwnd = self._create(flags, rect=rect, parent=parent)
         if not self.hwnd:
             raise sciter.SciterError("Could not create window")
 
         self.setup_callback(self.hwnd)
-        self.attach(window=self.hwnd)
+        self.attach(window=self.hwnd, subscription=subscription)
         pass
 
     def collapse(self, hide=False):
